# -*- coding: utf-8 -*-
class TicketLogsController < ApplicationController
  def update
    ticket_logs = TicketLogs.find(params[:id])
    ticket_logs.is_canceled = true
    ticket_logs.save

    @ticket = Ticket.find(ticket_logs.ticket_id)
    create_ticket_logs()
    @project_tickets = create_project_tickets(session[:project_id])
    load_ticket_attributes()
    @show_comment_only = true

    respond_to do |format|
      format.js { render template: 'tickets/update' }
    end
  end
end
